# Changelog

## v1.2.0
*Released on 2022-03-07*

### Changes
* Add `-n` option.

## v1.1.1
*Released on 2022-03-07*

### Bug fix
* Fix [#1](https://github.com/mdaeron/bibcites/issues/1#)

## v1.1.0
*Released on 2022-03-05*

### Changes
* Input BibTeX file is now an argument (`bibcites myfile.bib`) rather than an option (`bibcites -i myfile.bib`).
